[![pypi](https://img.shields.io/pypi/v/fink-utils.svg)](https://pypi.python.org/pypi/fink-utils)
[![PEP8](https://github.com/astrolabsoftware/fink-utils/workflows/PEP8/badge.svg)](https://github.com/astrolabsoftware/fink-utils/actions?query=workflow%3APEP8)

# fink-utils

Collection of useful functionalities used across the Fink ecosystem:

- [photometry](fink_utils/photometry): conversion routines between units
- [data](fink_utils/data): data manipulation with Python
- [spark](fink_utils/spark): data manipulation with Spark
- [xmatch](fink_utils/xmatch): utilities for manipulating external databases and catalogs
- [sso](fink_utils/sso): utilities for manipulating Solar System objects (HG, HG12, HG1G2, SHG1G2)
- [HBase](fink_utils/hbase): utilities for manipulating data stored in HBase
